# This customization file may provide 0, 1, or 2 functions
# to alter the way the configuration files for anonymous ftp
# are generated per site. In addition, certain variables may
# be specified in order to alter the way the ensim-generated
# configuration files are created, in case you would prefer
# to not have to write the code yourself. Below is a discussion
# of the variables and functions available to be modified.
#
# Note: if you wish to define either these variables of
# functions for all sites, you may copy this file into
# /usr/lib/ensim-python/site-packages/vh3/custom directory,
# renaming it to anonftp.py, and make your modifications.
# Please do not modify the file in its original location,
# as any changes made will be lost during an upgrade. 
# After copying the file to the location above, Webppliance must 
# be restarted before the customizations will start to take
# effect during site edits through the GUI.
#
# Note: if you wish to define either these variables or functions
# for a specific site, you may copy this file into the
# /home/virtual/site<n>/info/custom directory, renaming it
# to anonftp.py. Site-local customizations take priority over
# global customizations. That is, if the site-local
# customizations define one of the variables or functions
# listed below, then that variable or function will be used
# instead of the definition in the global customizations.

########################################
# Variables
########################################

# max_clients is used to set the maximum
# number of anonymous ftp connections that
# are allowed. The default is 5. Modify
# this assignment and uncomment it to have
# it set to something else.
# example: max_clients = 3
# max_clients = 5

########################################
# Functions
########################################

# nb_conf is the function that is called
# to generate the anonymous configuration
# for name-based sites. Below is an example
# of the configuration generated by default.
# If you choose to define this function,
# please pay attention to the lines marked
# with an (*) below. These lines are required
# in order for the service to work (the (*)
# should not be included in the content that
# you generate). Often there will be a comment
# above each of these lines explaining where to
# retrieve the information needed to generate
# them. More advanced python programmers may
# take advantage of the fact that there are two
# customizations modules, one global and one local,
# and if both are defined, the one containing
# the definition of this function is passed the
# other module via the cust parameter.
#
# Example configuration for nb_conf:
#
#      # The 'site1' should be replaced with the site argument to nb_conf
#  (*) <Anonymous /home/virtual/site1/fst/var/ftp>
#          <Limit LOGIN>
#              AllowAll
#          </Limit>
#          # Limit WRITE everywhere in the anonymous chroot
#          <Limit WRITE>
#              DenyAll
#          </Limit>
#          # An upload directory that allows storing files but not retrieving
#          # or creating directories.
#          <Directory uploads/*>
#              <Limit READ>
#                  DenyAll
#              </Limit>
#              <Limit STOR>
#                  AllowAll
#              </Limit>
#          </Directory>
#          MaxClients 5 "Sorry, the maximum number of allowed users are already connected (%%m)"
#          # 'site<n>' comes from first argument to nb_conf
#          TransferLog /home/virtual/site1/fst/var/log/xferlog
#          # this name of the user is obtained from
#          # newconf['siteinfo']['admin']
#  (*)     User admin1
#          # this number in this line is obtained from
#          # pwd.getpwnam(newconf['siteinfo']['admin'])[3]
#  (*)     Group 509
#  (*)     RequireValidShell off
#          # Technically, only one of the next two lines is
#          # required. These lines simply control what logins
#          # people may use to access anonymous ftp to the site.
#          # The domain in the next two lines is obtained
#          # from newconf['siteinfo']['domain']. The name of
#          # the user is from newconf['siteinfo']['admin'].
#          # If this domain has domain aliases, and you wish
#          # to be able to access anonymous ftp using the aliases,
#          # you will need to create additional lines like these
#          # for each alias. The list of aliases can be obtained
#          # by aliases = eval(newconf['aliases']['aliases'])
#  (*)     UserAlias anonymous@ensim.com admin1
#  (*)     UserAlias ftp@ensim.com admin1
#          DirFakeGroup on ftp
#          DirFakeUser on ftp
#  (*) </Anonymous>
#
# def nb_conf(site, newconf, oldconf, cust):


# ip_conf is the function that is called
# to generate the anonymous configuration
# for IP-based sites. Below is an example
# of the configuration generated by default.
# If you choose to define this function,
# please pay attention to the lines marked
# with an (*) below. These lines are required
# in order for the service to work (the (*)
# should not be included in the content that
# you generate). Often there will be a comment
# above each of these lines explaining where to
# retrieve the information needed to generate
# them. More advanced python programmers may
# take advantage of the fact that there are two
# customizations modules, one global and one local,
# and if both are defined, the one containing
# the definition of this function is passed the
# other module via the cust parameter.
#
# Example configuration for ip_conf:
#
#      # Note: all virtual domain directories in this
#      # container should be referenced as if they existed
#      # directly under /, and not under /home/virtual/site<n>/fst.
#
#  (*) <Anonymous /var/ftp>
#          <Limit LOGIN>
#              AllowAll
#          </Limit>
#          # Limit WRITE everywhere in the anonymous chroot
#          <Limit WRITE>
#              DenyAll
#          </Limit>
#          # An upload directory that allows storing files but not retrieving
#          # or creating directories.
#          <Directory uploads/*>
#              <Limit READ>
#                  DenyAll
#              </Limit>
#              <Limit STOR>
#                  AllowAll
#              </Limit>
#          </Directory>
#          MaxClients 5 "Sorry, the maximum number of allowed users are already connected (%%m)"
#  (*)     User ftp
#  (*)     Group ftp
#          UserAlias anonymous ftp
#  (*) </Anonymous>
#
# def ip_conf(site, newconf, oldconf, cust):
